Dragées - mariage, baptême - contenants, boites dragées - Confiserie Massardier
Description: Dragées Massardier : Dragées mariage et contenant baptême ou communion. Nos kits dragées uniques et originales, ballotins, boites et accessoires dragées. Thème dragées mariage, Thème dragées baptême
Keywords: dragées,dragées mariage,dragées baptême,dragées communion,boite mariage,dragées chocolat,dragées amandes,dragées avola,contenant dragées,ballotins dragées, kit dragées

Votre panier - Satisfait ou remboursé, 14 jours pour changer

| Panier

0 article(s)
Recherche

Recherche avancée

Panier | Identification | Livraison | Paiement | Validation
Identifiez-vous
Vous êtes nouveau client ?
Vous avez déjà un compte ?
Votre e-mail : |
Votre mot de passe : | Mot de passe oublié ?
CONFISERIE MASSARDIER Zone Corata 4 chemin du Pourquier 30250 Sommières FRANCE Tél. : 04.66.93.80.04 Fax : Email daniel@dragees-massardier.fr Siret : 413 256 397 00030 Code APE/NAF : 4791B / Vente à distance sur catalogue spécialisé TVA intra-communautaire : FR78413256397 Num CNIL : 1587031